{% extends "admin:admin/change_form.html" %}
{% load i18n %}

{% block object-tools-items %}
    {% if has_moderate_tool %}<li><a href="moderate/" class="historylink">{% trans "Moderate" %}</a></li>{% endif %}
    <li><a href="history/" class="historylink">{% trans "History" %}</a></li>
    {% if has_absolute_url %}<li><a href="../../../r/{{ content_type_id }}/{{ object_id }}/" class="viewsitelink">{% trans "View on site" %}</a></li>{% endif%}
{% endblock %}